[gcalctool] Fix incorrect spelling of ones' and two's complement (Bug #642457)



commit 00a42ac05797661ae11bc9d99b0955a33cb20676
Author: Robert Ancell <robert ancell canonical com>
Date:   Thu Feb 17 13:21:41 2011 +1100

    Fix incorrect spelling of ones' and two's complement (Bug #642457)

 src/math-buttons.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/math-buttons.c b/src/math-buttons.c
index 4295ff2..aadbed1 100644
--- a/src/math-buttons.c
+++ b/src/math-buttons.c
@@ -212,11 +212,11 @@ static ButtonData button_data[] = {
       /* Tooltip for the imaginary component button */
       N_("Imaginary Component")},
     {"ones_complement",    "ones ", FUNCTION,
-      /* Tooltip for the ones complement button */
-      N_("Ones Complement")},
+      /* Tooltip for the ones' complement button */
+      N_("Ones' Complement")},
     {"twos_complement",    "twos ", FUNCTION,
-      /* Tooltip for the twos complement button */
-      N_("Twos Complement")},
+      /* Tooltip for the two's complement button */
+      N_("Two's Complement")},
     {"trunc",              "trunc ", FUNCTION,
       /* Tooltip for the truncate button */
       N_("Truncate")},



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]